import { ExceptionOptionType as __ExceptionOptionType } from "@smithy/smithy-client";
import { DataBrewServiceException as __BaseException } from "./DataBrewServiceException";
export declare class AccessDeniedException extends __BaseException {
  readonly name: "AccessDeniedException";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<AccessDeniedException, __BaseException>
  );
}
export interface AllowedStatistics {
  Statistics: string[] | undefined;
}
export declare const AnalyticsMode: {
  readonly DISABLE: "DISABLE";
  readonly ENABLE: "ENABLE";
};
export type AnalyticsMode = (typeof AnalyticsMode)[keyof typeof AnalyticsMode];
export interface BatchDeleteRecipeVersionRequest {
  Name: string | undefined;
  RecipeVersions: string[] | undefined;
}
export interface RecipeVersionErrorDetail {
  ErrorCode?: string | undefined;
  ErrorMessage?: string | undefined;
  RecipeVersion?: string | undefined;
}
export interface BatchDeleteRecipeVersionResponse {
  Name: string | undefined;
  Errors?: RecipeVersionErrorDetail[] | undefined;
}
export declare class ConflictException extends __BaseException {
  readonly name: "ConflictException";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(opts: __ExceptionOptionType<ConflictException, __BaseException>);
}
export declare class ResourceNotFoundException extends __BaseException {
  readonly name: "ResourceNotFoundException";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<ResourceNotFoundException, __BaseException>
  );
}
export declare class ValidationException extends __BaseException {
  readonly name: "ValidationException";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<ValidationException, __BaseException>
  );
}
export declare const InputFormat: {
  readonly CSV: "CSV";
  readonly EXCEL: "EXCEL";
  readonly JSON: "JSON";
  readonly ORC: "ORC";
  readonly PARQUET: "PARQUET";
};
export type InputFormat = (typeof InputFormat)[keyof typeof InputFormat];
export interface CsvOptions {
  Delimiter?: string | undefined;
  HeaderRow?: boolean | undefined;
}
export interface ExcelOptions {
  SheetNames?: string[] | undefined;
  SheetIndexes?: number[] | undefined;
  HeaderRow?: boolean | undefined;
}
export interface JsonOptions {
  MultiLine?: boolean | undefined;
}
export interface FormatOptions {
  Json?: JsonOptions | undefined;
  Excel?: ExcelOptions | undefined;
  Csv?: CsvOptions | undefined;
}
export interface S3Location {
  Bucket: string | undefined;
  Key?: string | undefined;
  BucketOwner?: string | undefined;
}
export interface DatabaseInputDefinition {
  GlueConnectionName: string | undefined;
  DatabaseTableName?: string | undefined;
  TempDirectory?: S3Location | undefined;
  QueryString?: string | undefined;
}
export interface DataCatalogInputDefinition {
  CatalogId?: string | undefined;
  DatabaseName: string | undefined;
  TableName: string | undefined;
  TempDirectory?: S3Location | undefined;
}
export interface Metadata {
  SourceArn?: string | undefined;
}
export interface Input {
  S3InputDefinition?: S3Location | undefined;
  DataCatalogInputDefinition?: DataCatalogInputDefinition | undefined;
  DatabaseInputDefinition?: DatabaseInputDefinition | undefined;
  Metadata?: Metadata | undefined;
}
export declare const Order: {
  readonly ASCENDING: "ASCENDING";
  readonly DESCENDING: "DESCENDING";
};
export type Order = (typeof Order)[keyof typeof Order];
export declare const OrderedBy: {
  readonly LAST_MODIFIED_DATE: "LAST_MODIFIED_DATE";
};
export type OrderedBy = (typeof OrderedBy)[keyof typeof OrderedBy];
export interface FilesLimit {
  MaxFiles: number | undefined;
  OrderedBy?: OrderedBy | undefined;
  Order?: Order | undefined;
}
export interface FilterExpression {
  Expression: string | undefined;
  ValuesMap: Record<string, string> | undefined;
}
export interface DatetimeOptions {
  Format: string | undefined;
  TimezoneOffset?: string | undefined;
  LocaleCode?: string | undefined;
}
export declare const ParameterType: {
  readonly Datetime: "Datetime";
  readonly Number: "Number";
  readonly String: "String";
};
export type ParameterType = (typeof ParameterType)[keyof typeof ParameterType];
export interface DatasetParameter {
  Name: string | undefined;
  Type: ParameterType | undefined;
  DatetimeOptions?: DatetimeOptions | undefined;
  CreateColumn?: boolean | undefined;
  Filter?: FilterExpression | undefined;
}
export interface PathOptions {
  LastModifiedDateCondition?: FilterExpression | undefined;
  FilesLimit?: FilesLimit | undefined;
  Parameters?: Record<string, DatasetParameter> | undefined;
}
export interface CreateDatasetRequest {
  Name: string | undefined;
  Format?: InputFormat | undefined;
  FormatOptions?: FormatOptions | undefined;
  Input: Input | undefined;
  PathOptions?: PathOptions | undefined;
  Tags?: Record<string, string> | undefined;
}
export interface CreateDatasetResponse {
  Name: string | undefined;
}
export declare class ServiceQuotaExceededException extends __BaseException {
  readonly name: "ServiceQuotaExceededException";
  readonly $fault: "client";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<ServiceQuotaExceededException, __BaseException>
  );
}
export interface ColumnSelector {
  Regex?: string | undefined;
  Name?: string | undefined;
}
export interface StatisticOverride {
  Statistic: string | undefined;
  Parameters: Record<string, string> | undefined;
}
export interface StatisticsConfiguration {
  IncludedStatistics?: string[] | undefined;
  Overrides?: StatisticOverride[] | undefined;
}
export interface ColumnStatisticsConfiguration {
  Selectors?: ColumnSelector[] | undefined;
  Statistics: StatisticsConfiguration | undefined;
}
export interface EntityDetectorConfiguration {
  EntityTypes: string[] | undefined;
  AllowedStatistics?: AllowedStatistics[] | undefined;
}
export interface ProfileConfiguration {
  DatasetStatisticsConfiguration?: StatisticsConfiguration | undefined;
  ProfileColumns?: ColumnSelector[] | undefined;
  ColumnStatisticsConfigurations?: ColumnStatisticsConfiguration[] | undefined;
  EntityDetectorConfiguration?: EntityDetectorConfiguration | undefined;
}
export declare const EncryptionMode: {
  readonly SSEKMS: "SSE-KMS";
  readonly SSES3: "SSE-S3";
};
export type EncryptionMode =
  (typeof EncryptionMode)[keyof typeof EncryptionMode];
export declare const SampleMode: {
  readonly CUSTOM_ROWS: "CUSTOM_ROWS";
  readonly FULL_DATASET: "FULL_DATASET";
};
export type SampleMode = (typeof SampleMode)[keyof typeof SampleMode];
export interface JobSample {
  Mode?: SampleMode | undefined;
  Size?: number | undefined;
}
export declare const LogSubscription: {
  readonly DISABLE: "DISABLE";
  readonly ENABLE: "ENABLE";
};
export type LogSubscription =
  (typeof LogSubscription)[keyof typeof LogSubscription];
export declare const ValidationMode: {
  readonly CHECK_ALL: "CHECK_ALL";
};
export type ValidationMode =
  (typeof ValidationMode)[keyof typeof ValidationMode];
export interface ValidationConfiguration {
  RulesetArn: string | undefined;
  ValidationMode?: ValidationMode | undefined;
}
export interface CreateProfileJobRequest {
  DatasetName: string | undefined;
  EncryptionKeyArn?: string | undefined;
  EncryptionMode?: EncryptionMode | undefined;
  Name: string | undefined;
  LogSubscription?: LogSubscription | undefined;
  MaxCapacity?: number | undefined;
  MaxRetries?: number | undefined;
  OutputLocation: S3Location | undefined;
  Configuration?: ProfileConfiguration | undefined;
  ValidationConfigurations?: ValidationConfiguration[] | undefined;
  RoleArn: string | undefined;
  Tags?: Record<string, string> | undefined;
  Timeout?: number | undefined;
  JobSample?: JobSample | undefined;
}
export interface CreateProfileJobResponse {
  Name: string | undefined;
}
export declare const SampleType: {
  readonly FIRST_N: "FIRST_N";
  readonly LAST_N: "LAST_N";
  readonly RANDOM: "RANDOM";
};
export type SampleType = (typeof SampleType)[keyof typeof SampleType];
export interface Sample {
  Size?: number | undefined;
  Type: SampleType | undefined;
}
export interface CreateProjectRequest {
  DatasetName: string | undefined;
  Name: string | undefined;
  RecipeName: string | undefined;
  Sample?: Sample | undefined;
  RoleArn: string | undefined;
  Tags?: Record<string, string> | undefined;
}
export interface CreateProjectResponse {
  Name: string | undefined;
}
export declare class InternalServerException extends __BaseException {
  readonly name: "InternalServerException";
  readonly $fault: "server";
  Message?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<InternalServerException, __BaseException>
  );
}
export interface RecipeAction {
  Operation: string | undefined;
  Parameters?: Record<string, string> | undefined;
}
export interface ConditionExpression {
  Condition: string | undefined;
  Value?: string | undefined;
  TargetColumn: string | undefined;
}
export interface RecipeStep {
  Action: RecipeAction | undefined;
  ConditionExpressions?: ConditionExpression[] | undefined;
}
export interface CreateRecipeRequest {
  Description?: string | undefined;
  Name: string | undefined;
  Steps: RecipeStep[] | undefined;
  Tags?: Record<string, string> | undefined;
}
export interface CreateRecipeResponse {
  Name: string | undefined;
}
export interface DatabaseTableOutputOptions {
  TempDirectory?: S3Location | undefined;
  TableName: string | undefined;
}
export declare const DatabaseOutputMode: {
  readonly NEW_TABLE: "NEW_TABLE";
};
export type DatabaseOutputMode =
  (typeof DatabaseOutputMode)[keyof typeof DatabaseOutputMode];
export interface DatabaseOutput {
  GlueConnectionName: string | undefined;
  DatabaseOptions: DatabaseTableOutputOptions | undefined;
  DatabaseOutputMode?: DatabaseOutputMode | undefined;
}
export interface S3TableOutputOptions {
  Location: S3Location | undefined;
}
export interface DataCatalogOutput {
  CatalogId?: string | undefined;
  DatabaseName: string | undefined;
  TableName: string | undefined;
  S3Options?: S3TableOutputOptions | undefined;
  DatabaseOptions?: DatabaseTableOutputOptions | undefined;
  Overwrite?: boolean | undefined;
}
export declare const CompressionFormat: {
  readonly BROTLI: "BROTLI";
  readonly BZIP2: "BZIP2";
  readonly DEFLATE: "DEFLATE";
  readonly GZIP: "GZIP";
  readonly LZ4: "LZ4";
  readonly LZO: "LZO";
  readonly SNAPPY: "SNAPPY";
  readonly ZLIB: "ZLIB";
  readonly ZSTD: "ZSTD";
};
export type CompressionFormat =
  (typeof CompressionFormat)[keyof typeof CompressionFormat];
export declare const OutputFormat: {
  readonly AVRO: "AVRO";
  readonly CSV: "CSV";
  readonly GLUEPARQUET: "GLUEPARQUET";
  readonly JSON: "JSON";
  readonly ORC: "ORC";
  readonly PARQUET: "PARQUET";
  readonly TABLEAUHYPER: "TABLEAUHYPER";
  readonly XML: "XML";
};
export type OutputFormat = (typeof OutputFormat)[keyof typeof OutputFormat];
export interface CsvOutputOptions {
  Delimiter?: string | undefined;
}
export interface OutputFormatOptions {
  Csv?: CsvOutputOptions | undefined;
}
export interface Output {
  CompressionFormat?: CompressionFormat | undefined;
  Format?: OutputFormat | undefined;
  PartitionColumns?: string[] | undefined;
  Location: S3Location | undefined;
  Overwrite?: boolean | undefined;
  FormatOptions?: OutputFormatOptions | undefined;
  MaxOutputFiles?: number | undefined;
}
export interface RecipeReference {
  Name: string | undefined;
  RecipeVersion?: string | undefined;
}
export interface CreateRecipeJobRequest {
  DatasetName?: string | undefined;
  EncryptionKeyArn?: string | undefined;
  EncryptionMode?: EncryptionMode | undefined;
  Name: string | undefined;
  LogSubscription?: LogSubscription | undefined;
  MaxCapacity?: number | undefined;
  MaxRetries?: number | undefined;
  Outputs?: Output[] | undefined;
  DataCatalogOutputs?: DataCatalogOutput[] | undefined;
  DatabaseOutputs?: DatabaseOutput[] | undefined;
  ProjectName?: string | undefined;
  RecipeReference?: RecipeReference | undefined;
  RoleArn: string | undefined;
  Tags?: Record<string, string> | undefined;
  Timeout?: number | undefined;
}
export interface CreateRecipeJobResponse {
  Name: string | undefined;
}
export declare const ThresholdType: {
  readonly GREATER_THAN: "GREATER_THAN";
  readonly GREATER_THAN_OR_EQUAL: "GREATER_THAN_OR_EQUAL";
  readonly LESS_THAN: "LESS_THAN";
  readonly LESS_THAN_OR_EQUAL: "LESS_THAN_OR_EQUAL";
};
export type ThresholdType = (typeof ThresholdType)[keyof typeof ThresholdType];
export declare const ThresholdUnit: {
  readonly COUNT: "COUNT";
  readonly PERCENTAGE: "PERCENTAGE";
};
export type ThresholdUnit = (typeof ThresholdUnit)[keyof typeof ThresholdUnit];
export interface Threshold {
  Value: number | undefined;
  Type?: ThresholdType | undefined;
  Unit?: ThresholdUnit | undefined;
}
export interface Rule {
  Name: string | undefined;
  Disabled?: boolean | undefined;
  CheckExpression: string | undefined;
  SubstitutionMap?: Record<string, string> | undefined;
  Threshold?: Threshold | undefined;
  ColumnSelectors?: ColumnSelector[] | undefined;
}
export interface CreateRulesetRequest {
  Name: string | undefined;
  Description?: string | undefined;
  TargetArn: string | undefined;
  Rules: Rule[] | undefined;
  Tags?: Record<string, string> | undefined;
}
export interface CreateRulesetResponse {
  Name: string | undefined;
}
export interface CreateScheduleRequest {
  JobNames?: string[] | undefined;
  CronExpression: string | undefined;
  Tags?: Record<string, string> | undefined;
  Name: string | undefined;
}
export interface CreateScheduleResponse {
  Name: string | undefined;
}
export interface DeleteDatasetRequest {
  Name: string | undefined;
}
export interface DeleteDatasetResponse {
  Name: string | undefined;
}
export interface DeleteJobRequest {
  Name: string | undefined;
}
export interface DeleteJobResponse {
  Name: string | undefined;
}
export interface DeleteProjectRequest {
  Name: string | undefined;
}
export interface DeleteProjectResponse {
  Name: string | undefined;
}
export interface DeleteRecipeVersionRequest {
  Name: string | undefined;
  RecipeVersion: string | undefined;
}
export interface DeleteRecipeVersionResponse {
  Name: string | undefined;
  RecipeVersion: string | undefined;
}
export interface DeleteRulesetRequest {
  Name: string | undefined;
}
export interface DeleteRulesetResponse {
  Name: string | undefined;
}
export interface DeleteScheduleRequest {
  Name: string | undefined;
}
export interface DeleteScheduleResponse {
  Name: string | undefined;
}
export interface DescribeDatasetRequest {
  Name: string | undefined;
}
export declare const Source: {
  readonly DATABASE: "DATABASE";
  readonly DATACATALOG: "DATA-CATALOG";
  readonly S3: "S3";
};
export type Source = (typeof Source)[keyof typeof Source];
export interface DescribeDatasetResponse {
  CreatedBy?: string | undefined;
  CreateDate?: Date | undefined;
  Name: string | undefined;
  Format?: InputFormat | undefined;
  FormatOptions?: FormatOptions | undefined;
  Input: Input | undefined;
  LastModifiedDate?: Date | undefined;
  LastModifiedBy?: string | undefined;
  Source?: Source | undefined;
  PathOptions?: PathOptions | undefined;
  Tags?: Record<string, string> | undefined;
  ResourceArn?: string | undefined;
}
export interface DescribeJobRequest {
  Name: string | undefined;
}
export declare const JobType: {
  readonly PROFILE: "PROFILE";
  readonly RECIPE: "RECIPE";
};
export type JobType = (typeof JobType)[keyof typeof JobType];
export interface DescribeJobResponse {
  CreateDate?: Date | undefined;
  CreatedBy?: string | undefined;
  DatasetName?: string | undefined;
  EncryptionKeyArn?: string | undefined;
  EncryptionMode?: EncryptionMode | undefined;
  Name: string | undefined;
  Type?: JobType | undefined;
  LastModifiedBy?: string | undefined;
  LastModifiedDate?: Date | undefined;
  LogSubscription?: LogSubscription | undefined;
  MaxCapacity?: number | undefined;
  MaxRetries?: number | undefined;
  Outputs?: Output[] | undefined;
  DataCatalogOutputs?: DataCatalogOutput[] | undefined;
  DatabaseOutputs?: DatabaseOutput[] | undefined;
  ProjectName?: string | undefined;
  ProfileConfiguration?: ProfileConfiguration | undefined;
  ValidationConfigurations?: ValidationConfiguration[] | undefined;
  RecipeReference?: RecipeReference | undefined;
  ResourceArn?: string | undefined;
  RoleArn?: string | undefined;
  Tags?: Record<string, string> | undefined;
  Timeout?: number | undefined;
  JobSample?: JobSample | undefined;
}
export interface DescribeJobRunRequest {
  Name: string | undefined;
  RunId: string | undefined;
}
export declare const JobRunState: {
  readonly FAILED: "FAILED";
  readonly RUNNING: "RUNNING";
  readonly STARTING: "STARTING";
  readonly STOPPED: "STOPPED";
  readonly STOPPING: "STOPPING";
  readonly SUCCEEDED: "SUCCEEDED";
  readonly TIMEOUT: "TIMEOUT";
};
export type JobRunState = (typeof JobRunState)[keyof typeof JobRunState];
export interface DescribeJobRunResponse {
  Attempt?: number | undefined;
  CompletedOn?: Date | undefined;
  DatasetName?: string | undefined;
  ErrorMessage?: string | undefined;
  ExecutionTime?: number | undefined;
  JobName: string | undefined;
  ProfileConfiguration?: ProfileConfiguration | undefined;
  ValidationConfigurations?: ValidationConfiguration[] | undefined;
  RunId?: string | undefined;
  State?: JobRunState | undefined;
  LogSubscription?: LogSubscription | undefined;
  LogGroupName?: string | undefined;
  Outputs?: Output[] | undefined;
  DataCatalogOutputs?: DataCatalogOutput[] | undefined;
  DatabaseOutputs?: DatabaseOutput[] | undefined;
  RecipeReference?: RecipeReference | undefined;
  StartedBy?: string | undefined;
  StartedOn?: Date | undefined;
  JobSample?: JobSample | undefined;
}
export interface DescribeProjectRequest {
  Name: string | undefined;
}
export declare const SessionStatus: {
  readonly ASSIGNED: "ASSIGNED";
  readonly FAILED: "FAILED";
  readonly INITIALIZING: "INITIALIZING";
  readonly PROVISIONING: "PROVISIONING";
  readonly READY: "READY";
  readonly RECYCLING: "RECYCLING";
  readonly ROTATING: "ROTATING";
  readonly TERMINATED: "TERMINATED";
  readonly TERMINATING: "TERMINATING";
  readonly UPDATING: "UPDATING";
};
export type SessionStatus = (typeof SessionStatus)[keyof typeof SessionStatus];
export interface DescribeProjectResponse {
  CreateDate?: Date | undefined;
  CreatedBy?: string | undefined;
  DatasetName?: string | undefined;
  LastModifiedDate?: Date | undefined;
  LastModifiedBy?: string | undefined;
  Name: string | undefined;
  RecipeName?: string | undefined;
  ResourceArn?: string | undefined;
  Sample?: Sample | undefined;
  RoleArn?: string | undefined;
  Tags?: Record<string, string> | undefined;
  SessionStatus?: SessionStatus | undefined;
  OpenedBy?: string | undefined;
  OpenDate?: Date | undefined;
}
export interface DescribeRecipeRequest {
  Name: string | undefined;
  RecipeVersion?: string | undefined;
}
export interface DescribeRecipeResponse {
  CreatedBy?: string | undefined;
  CreateDate?: Date | undefined;
  LastModifiedBy?: string | undefined;
  LastModifiedDate?: Date | undefined;
  ProjectName?: string | undefined;
  PublishedBy?: string | undefined;
  PublishedDate?: Date | undefined;
  Description?: string | undefined;
  Name: string | undefined;
  Steps?: RecipeStep[] | undefined;
  Tags?: Record<string, string> | undefined;
  ResourceArn?: string | undefined;
  RecipeVersion?: string | undefined;
}
export interface DescribeRulesetRequest {
  Name: string | undefined;
}
export interface DescribeRulesetResponse {
  Name: string | undefined;
  Description?: string | undefined;
  TargetArn?: string | undefined;
  Rules?: Rule[] | undefined;
  CreateDate?: Date | undefined;
  CreatedBy?: string | undefined;
  LastModifiedBy?: string | undefined;
  LastModifiedDate?: Date | undefined;
  ResourceArn?: string | undefined;
  Tags?: Record<string, string> | undefined;
}
export interface DescribeScheduleRequest {
  Name: string | undefined;
}
export interface DescribeScheduleResponse {
  CreateDate?: Date | undefined;
  CreatedBy?: string | undefined;
  JobNames?: string[] | undefined;
  LastModifiedBy?: string | undefined;
  LastModifiedDate?: Date | undefined;
  ResourceArn?: string | undefined;
  CronExpression?: string | undefined;
  Tags?: Record<string, string> | undefined;
  Name: string | undefined;
}
export interface ListDatasetsRequest {
  MaxResults?: number | undefined;
  NextToken?: string | undefined;
}
export interface Dataset {
  AccountId?: string | undefined;
  CreatedBy?: string | undefined;
  CreateDate?: Date | undefined;
  Name: string | undefined;
  Format?: InputFormat | undefined;
  FormatOptions?: FormatOptions | undefined;
  Input: Input | undefined;
  LastModifiedDate?: Date | undefined;
  LastModifiedBy?: string | undefined;
  Source?: Source | undefined;
  PathOptions?: PathOptions | undefined;
  Tags?: Record<string, string> | undefined;
  ResourceArn?: string | undefined;
}
export interface ListDatasetsResponse {
  Datasets: Dataset[] | undefined;
  NextToken?: string | undefined;
}
export interface ListJobRunsRequest {
  Name: string | undefined;
  MaxResults?: number | undefined;
  NextToken?: string | undefined;
}
export interface JobRun {
  Attempt?: number | undefined;
  CompletedOn?: Date | undefined;
  DatasetName?: string | undefined;
  ErrorMessage?: string | undefined;
  ExecutionTime?: number | undefined;
  JobName?: string | undefined;
  RunId?: string | undefined;
  State?: JobRunState | undefined;
  LogSubscription?: LogSubscription | undefined;
  LogGroupName?: string | undefined;
  Outputs?: Output[] | undefined;
  DataCatalogOutputs?: DataCatalogOutput[] | undefined;
  DatabaseOutputs?: DatabaseOutput[] | undefined;
  RecipeReference?: RecipeReference | undefined;
  StartedBy?: string | undefined;
  StartedOn?: Date | undefined;
  JobSample?: JobSample | undefined;
  ValidationConfigurations?: ValidationConfiguration[] | undefined;
}
export interface ListJobRunsResponse {
  JobRuns: JobRun[] | undefined;
  NextToken?: string | undefined;
}
export interface ListJobsRequest {
  DatasetName?: string | undefined;
  MaxResults?: number | undefined;
  NextToken?: string | undefined;
  ProjectName?: string | undefined;
}
export interface Job {
  AccountId?: string | undefined;
  CreatedBy?: string | undefined;
  CreateDate?: Date | undefined;
  DatasetName?: string | undefined;
  EncryptionKeyArn?: string | undefined;
  EncryptionMode?: EncryptionMode | undefined;
  Name: string | undefined;
  Type?: JobType | undefined;
  LastModifiedBy?: string | undefined;
  LastModifiedDate?: Date | undefined;
  LogSubscription?: LogSubscription | undefined;
  MaxCapacity?: number | undefined;
  MaxRetries?: number | undefined;
  Outputs?: Output[] | undefined;
  DataCatalogOutputs?: DataCatalogOutput[] | undefined;
  DatabaseOutputs?: DatabaseOutput[] | undefined;
  ProjectName?: string | undefined;
  RecipeReference?: RecipeReference | undefined;
  ResourceArn?: string | undefined;
  RoleArn?: string | undefined;
  Timeout?: number | undefined;
  Tags?: Record<string, string> | undefined;
  JobSample?: JobSample | undefined;
  ValidationConfigurations?: ValidationConfiguration[] | undefined;
}
export interface ListJobsResponse {
  Jobs: Job[] | undefined;
  NextToken?: string | undefined;
}
export interface ListProjectsRequest {
  NextToken?: string | undefined;
  MaxResults?: number | undefined;
}
export interface Project {
  AccountId?: string | undefined;
  CreateDate?: Date | undefined;
  CreatedBy?: string | undefined;
  DatasetName?: string | undefined;
  LastModifiedDate?: Date | undefined;
  LastModifiedBy?: string | undefined;
  Name: string | undefined;
  RecipeName: string | undefined;
  ResourceArn?: string | undefined;
  Sample?: Sample | undefined;
  Tags?: Record<string, string> | undefined;
  RoleArn?: string | undefined;
  OpenedBy?: string | undefined;
  OpenDate?: Date | undefined;
}
export interface ListProjectsResponse {
  Projects: Project[] | undefined;
  NextToken?: string | undefined;
}
export interface ListRecipesRequest {
  MaxResults?: number | undefined;
  NextToken?: string | undefined;
  RecipeVersion?: string | undefined;
}
export interface Recipe {
  CreatedBy?: string | undefined;
  CreateDate?: Date | undefined;
  LastModifiedBy?: string | undefined;
  LastModifiedDate?: Date | undefined;
  ProjectName?: string | undefined;
  PublishedBy?: string | undefined;
  PublishedDate?: Date | undefined;
  Description?: string | undefined;
  Name: string | undefined;
  ResourceArn?: string | undefined;
  Steps?: RecipeStep[] | undefined;
  Tags?: Record<string, string> | undefined;
  RecipeVersion?: string | undefined;
}
export interface ListRecipesResponse {
  Recipes: Recipe[] | undefined;
  NextToken?: string | undefined;
}
export interface ListRecipeVersionsRequest {
  MaxResults?: number | undefined;
  NextToken?: string | undefined;
  Name: string | undefined;
}
export interface ListRecipeVersionsResponse {
  NextToken?: string | undefined;
  Recipes: Recipe[] | undefined;
}
export interface ListRulesetsRequest {
  TargetArn?: string | undefined;
  MaxResults?: number | undefined;
  NextToken?: string | undefined;
}
export interface RulesetItem {
  AccountId?: string | undefined;
  CreatedBy?: string | undefined;
  CreateDate?: Date | undefined;
  Description?: string | undefined;
  LastModifiedBy?: string | undefined;
  LastModifiedDate?: Date | undefined;
  Name: string | undefined;
  ResourceArn?: string | undefined;
  RuleCount?: number | undefined;
  Tags?: Record<string, string> | undefined;
  TargetArn: string | undefined;
}
export interface ListRulesetsResponse {
  Rulesets: RulesetItem[] | undefined;
  NextToken?: string | undefined;
}
export interface ListSchedulesRequest {
  JobName?: string | undefined;
  MaxResults?: number | undefined;
  NextToken?: string | undefined;
}
export interface Schedule {
  AccountId?: string | undefined;
  CreatedBy?: string | undefined;
  CreateDate?: Date | undefined;
  JobNames?: string[] | undefined;
  LastModifiedBy?: string | undefined;
  LastModifiedDate?: Date | undefined;
  ResourceArn?: string | undefined;
  CronExpression?: string | undefined;
  Tags?: Record<string, string> | undefined;
  Name: string | undefined;
}
export interface ListSchedulesResponse {
  Schedules: Schedule[] | undefined;
  NextToken?: string | undefined;
}
export interface ListTagsForResourceRequest {
  ResourceArn: string | undefined;
}
export interface ListTagsForResourceResponse {
  Tags?: Record<string, string> | undefined;
}
export interface PublishRecipeRequest {
  Description?: string | undefined;
  Name: string | undefined;
}
export interface PublishRecipeResponse {
  Name: string | undefined;
}
export interface ViewFrame {
  StartColumnIndex: number | undefined;
  ColumnRange?: number | undefined;
  HiddenColumns?: string[] | undefined;
  StartRowIndex?: number | undefined;
  RowRange?: number | undefined;
  Analytics?: AnalyticsMode | undefined;
}
export interface SendProjectSessionActionRequest {
  Preview?: boolean | undefined;
  Name: string | undefined;
  RecipeStep?: RecipeStep | undefined;
  StepIndex?: number | undefined;
  ClientSessionId?: string | undefined;
  ViewFrame?: ViewFrame | undefined;
}
export interface SendProjectSessionActionResponse {
  Result?: string | undefined;
  Name: string | undefined;
  ActionId?: number | undefined;
}
export interface StartJobRunRequest {
  Name: string | undefined;
}
export interface StartJobRunResponse {
  RunId: string | undefined;
}
export interface StartProjectSessionRequest {
  Name: string | undefined;
  AssumeControl?: boolean | undefined;
}
export interface StartProjectSessionResponse {
  Name: string | undefined;
  ClientSessionId?: string | undefined;
}
export interface StopJobRunRequest {
  Name: string | undefined;
  RunId: string | undefined;
}
export interface StopJobRunResponse {
  RunId: string | undefined;
}
export interface TagResourceRequest {
  ResourceArn: string | undefined;
  Tags: Record<string, string> | undefined;
}
export interface TagResourceResponse {}
export interface UntagResourceRequest {
  ResourceArn: string | undefined;
  TagKeys: string[] | undefined;
}
export interface UntagResourceResponse {}
export interface UpdateDatasetRequest {
  Name: string | undefined;
  Format?: InputFormat | undefined;
  FormatOptions?: FormatOptions | undefined;
  Input: Input | undefined;
  PathOptions?: PathOptions | undefined;
}
export interface UpdateDatasetResponse {
  Name: string | undefined;
}
export interface UpdateProfileJobRequest {
  Configuration?: ProfileConfiguration | undefined;
  EncryptionKeyArn?: string | undefined;
  EncryptionMode?: EncryptionMode | undefined;
  Name: string | undefined;
  LogSubscription?: LogSubscription | undefined;
  MaxCapacity?: number | undefined;
  MaxRetries?: number | undefined;
  OutputLocation: S3Location | undefined;
  ValidationConfigurations?: ValidationConfiguration[] | undefined;
  RoleArn: string | undefined;
  Timeout?: number | undefined;
  JobSample?: JobSample | undefined;
}
export interface UpdateProfileJobResponse {
  Name: string | undefined;
}
export interface UpdateProjectRequest {
  Sample?: Sample | undefined;
  RoleArn: string | undefined;
  Name: string | undefined;
}
export interface UpdateProjectResponse {
  LastModifiedDate?: Date | undefined;
  Name: string | undefined;
}
export interface UpdateRecipeRequest {
  Description?: string | undefined;
  Name: string | undefined;
  Steps?: RecipeStep[] | undefined;
}
export interface UpdateRecipeResponse {
  Name: string | undefined;
}
export interface UpdateRecipeJobRequest {
  EncryptionKeyArn?: string | undefined;
  EncryptionMode?: EncryptionMode | undefined;
  Name: string | undefined;
  LogSubscription?: LogSubscription | undefined;
  MaxCapacity?: number | undefined;
  MaxRetries?: number | undefined;
  Outputs?: Output[] | undefined;
  DataCatalogOutputs?: DataCatalogOutput[] | undefined;
  DatabaseOutputs?: DatabaseOutput[] | undefined;
  RoleArn: string | undefined;
  Timeout?: number | undefined;
}
export interface UpdateRecipeJobResponse {
  Name: string | undefined;
}
export interface UpdateRulesetRequest {
  Name: string | undefined;
  Description?: string | undefined;
  Rules: Rule[] | undefined;
}
export interface UpdateRulesetResponse {
  Name: string | undefined;
}
export interface UpdateScheduleRequest {
  JobNames?: string[] | undefined;
  CronExpression: string | undefined;
  Name: string | undefined;
}
export interface UpdateScheduleResponse {
  Name: string | undefined;
}
export declare const SendProjectSessionActionRequestFilterSensitiveLog: (
  obj: SendProjectSessionActionRequest
) => any;
export declare const StartProjectSessionResponseFilterSensitiveLog: (
  obj: StartProjectSessionResponse
) => any;
